@@ -7,6 +7,7 @@ from .functions import (
     render_statement,
     sort_query,
     table_name,
+    with_backrefs
 )
 from .listeners import coercion_listener
 from .merge import merge, Merger
@@ -14,6 +15,8 @@ from .proxy_dict import ProxyDict, proxy_dict
 from .types import (
     ArrowType,
     ColorType,
+    CountryType,
+    Country,
     EmailType,
     instrumented_list,
     InstrumentedList,
@@ -34,7 +37,7 @@ from .types import (
 )
 
 
-__version__ = '0.16.5'
+__version__ = '0.16.6'
 
 
 __all__ = (
@@ -49,8 +52,11 @@ __all__ = (
     render_statement,
     sort_query,
     table_name,
+    with_backrefs,
     ArrowType,
     ColorType,
+    CountryType,
+    Country,
     EmailType,
     ImproperlyConfigured,
     InstrumentedList,
